"use client";
import {
  useCheckboxGroupContext
} from "./chunk-3XGO5KXW.mjs";

// src/use-checkbox.ts
import { useCallback, useId, useMemo, useRef, useState } from "react";
import {
  useCheckbox as useReactAriaCheckbox,
  useCheckboxGroupItem as useReactAriaCheckboxGroupItem
} from "@react-aria/checkbox";
import { useFocusRing } from "@react-aria/focus";
import { useHover } from "@react-aria/interactions";
import { chain, mergeProps } from "@react-aria/utils";
import { useToggleState } from "@react-stately/toggle";
import { dataAttr, mergeRefs } from "@koobiq-react/react-utils";
import { safeAriaLabel } from "@koobiq-react/shared-utils";
import { usePress } from "@koobiq-react/use-aria-press";
import { useCallbackRef } from "@koobiq-react/use-callback-ref";
import { useSafeLayoutEffect } from "@koobiq-react/use-safe-layout-effect";
function useCheckbox(props) {
  var _a;
  const groupContext = useCheckboxGroupContext();
  const isInGroup = !!groupContext;
  const {
    as,
    ref,
    value = "",
    children,
    icon,
    name,
    isRequired = false,
    isReadOnly: isReadOnlyProp = false,
    autoFocus = false,
    isSelected: isSelectedProp,
    validationState,
    isDisabled: isDisabledProp = false,
    isIndeterminate = false,
    isInvalid = validationState ? validationState === "invalid" : (_a = groupContext == null ? void 0 : groupContext.isInvalid) != null ? _a : false,
    defaultSelected,
    onValueChange,
    ...otherProps
  } = props;
  const Component = as || "label";
  const domRef = useRef(null);
  const inputRef = useRef(null);
  let onChange = props.onChange;
  if (isInGroup) {
    const dispatch = () => {
      groupContext.groupState.resetValidation();
    };
    onChange = chain(dispatch, onChange);
  }
  const labelId = useId();
  const ariaCheckboxProps = useMemo(() => {
    return {
      name,
      value,
      children,
      autoFocus,
      defaultSelected,
      isIndeterminate,
      isRequired,
      isSelected: isSelectedProp,
      isDisabled: isDisabledProp,
      isReadOnly: isReadOnlyProp,
      "aria-label": safeAriaLabel(otherProps["aria-label"], children),
      "aria-labelledby": otherProps["aria-labelledby"] || labelId,
      onChange: onValueChange
    };
  }, [
    value,
    name,
    labelId,
    children,
    autoFocus,
    isIndeterminate,
    isDisabledProp,
    isReadOnlyProp,
    isSelectedProp,
    defaultSelected,
    otherProps["aria-label"],
    otherProps["aria-labelledby"],
    onValueChange
  ]);
  const toggleState = useToggleState(ariaCheckboxProps);
  const {
    inputProps,
    isSelected,
    isDisabled,
    isReadOnly,
    isPressed: isPressedKeyboard
  } = isInGroup ? (
    // eslint-disable-next-line
    useReactAriaCheckboxGroupItem(
      {
        ...ariaCheckboxProps,
        isInvalid,
        validationBehavior: "native"
      },
      groupContext.groupState,
      inputRef
    )
  ) : (
    // eslint-disable-next-line
    useReactAriaCheckbox(
      { ...ariaCheckboxProps, validationBehavior: "native" },
      toggleState,
      inputRef
    )
  );
  const isInteractionDisabled = isDisabled || isReadOnly;
  const [isPressed, setPressed] = useState(false);
  const { pressProps } = usePress({
    isDisabled: isInteractionDisabled,
    onPressStart(e) {
      if (e.pointerType !== "keyboard") {
        setPressed(true);
      }
    },
    onPressEnd(e) {
      if (e.pointerType !== "keyboard") {
        setPressed(false);
      }
    }
  });
  const pressed = isInteractionDisabled ? false : isPressed || isPressedKeyboard;
  if (isRequired) {
    inputProps.required = true;
  }
  const { hoverProps, isHovered } = useHover({
    isDisabled: inputProps.disabled
  });
  const { focusProps, isFocused, isFocusVisible } = useFocusRing({
    autoFocus: inputProps.autoFocus
  });
  useSafeLayoutEffect(() => {
    if (!inputRef.current)
      return;
    const isInputRefChecked = !!inputRef.current.checked;
    toggleState.setSelected(isInputRefChecked);
  }, [inputRef.current]);
  const onChangeProp = useCallbackRef(onChange);
  const handleCheckboxChange = useCallback(
    (event) => {
      if (isReadOnly || isDisabled) {
        event.preventDefault();
        return;
      }
      onChangeProp == null ? void 0 : onChangeProp(event);
    },
    [isReadOnly, isDisabled, onChangeProp]
  );
  const getBaseProps = useCallback(() => {
    return {
      ref: domRef,
      "data-disabled": dataAttr(isDisabled),
      "data-selected": dataAttr(isSelected || isIndeterminate),
      "data-hover": dataAttr(isHovered),
      "data-focus": dataAttr(isFocused),
      "data-pressed": dataAttr(pressed),
      "data-readonly": dataAttr(inputProps.readOnly),
      "data-focus-visible": dataAttr(isFocusVisible),
      "data-indeterminate": dataAttr(isIndeterminate),
      ...mergeProps(hoverProps, pressProps, otherProps)
    };
  }, [
    isDisabled,
    isSelected,
    isIndeterminate,
    isHovered,
    isFocused,
    pressed,
    inputProps.readOnly,
    isFocusVisible,
    hoverProps,
    pressProps,
    otherProps
  ]);
  const getWrapperProps = useCallback((props2 = {}) => {
    return {
      ...props2,
      "aria-hidden": true
    };
  }, []);
  const getInputProps = useCallback(() => {
    return {
      ref: mergeRefs(inputRef, ref),
      ...mergeProps(inputProps, focusProps),
      onChange: chain(inputProps.onChange, handleCheckboxChange)
    };
  }, [inputProps, focusProps, handleCheckboxChange]);
  const getLabelProps = useCallback(
    () => ({
      id: labelId
    }),
    [isDisabled, isSelected]
  );
  const getIconProps = useCallback(
    () => ({
      isSelected,
      isIndeterminate: !!isIndeterminate
    }),
    [isSelected, isIndeterminate]
  );
  return {
    Component,
    icon,
    children,
    isSelected,
    isDisabled,
    isFocused,
    isHovered,
    isFocusVisible,
    getBaseProps,
    getWrapperProps,
    getInputProps,
    getLabelProps,
    getIconProps
  };
}

export {
  useCheckbox
};
