"use client";
"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/use-checkbox.ts
var use_checkbox_exports = {};
__export(use_checkbox_exports, {
  useCheckbox: () => useCheckbox
});
module.exports = __toCommonJS(use_checkbox_exports);
var import_react = require("react");
var import_checkbox = require("@react-aria/checkbox");
var import_focus = require("@react-aria/focus");
var import_interactions = require("@react-aria/interactions");
var import_utils = require("@react-aria/utils");
var import_toggle = require("@react-stately/toggle");
var import_react_utils2 = require("@koobiq-react/react-utils");
var import_shared_utils = require("@koobiq-react/shared-utils");
var import_use_aria_press = require("@koobiq-react/use-aria-press");
var import_use_callback_ref = require("@koobiq-react/use-callback-ref");
var import_use_safe_layout_effect = require("@koobiq-react/use-safe-layout-effect");

// src/checkbox-group-context.ts
var import_react_utils = require("@koobiq-react/react-utils");
var [CheckboxGroupProvider, useCheckboxGroupContext] = (0, import_react_utils.createContext)({
  name: "CheckboxGroupContext",
  strict: false
});

// src/use-checkbox.ts
function useCheckbox(props) {
  var _a;
  const groupContext = useCheckboxGroupContext();
  const isInGroup = !!groupContext;
  const {
    as,
    ref,
    value = "",
    children,
    icon,
    name,
    isRequired = false,
    isReadOnly: isReadOnlyProp = false,
    autoFocus = false,
    isSelected: isSelectedProp,
    validationState,
    isDisabled: isDisabledProp = false,
    isIndeterminate = false,
    isInvalid = validationState ? validationState === "invalid" : (_a = groupContext == null ? void 0 : groupContext.isInvalid) != null ? _a : false,
    defaultSelected,
    onValueChange,
    ...otherProps
  } = props;
  const Component = as || "label";
  const domRef = (0, import_react.useRef)(null);
  const inputRef = (0, import_react.useRef)(null);
  let onChange = props.onChange;
  if (isInGroup) {
    const dispatch = () => {
      groupContext.groupState.resetValidation();
    };
    onChange = (0, import_utils.chain)(dispatch, onChange);
  }
  const labelId = (0, import_react.useId)();
  const ariaCheckboxProps = (0, import_react.useMemo)(() => {
    return {
      name,
      value,
      children,
      autoFocus,
      defaultSelected,
      isIndeterminate,
      isRequired,
      isSelected: isSelectedProp,
      isDisabled: isDisabledProp,
      isReadOnly: isReadOnlyProp,
      "aria-label": (0, import_shared_utils.safeAriaLabel)(otherProps["aria-label"], children),
      "aria-labelledby": otherProps["aria-labelledby"] || labelId,
      onChange: onValueChange
    };
  }, [
    value,
    name,
    labelId,
    children,
    autoFocus,
    isIndeterminate,
    isDisabledProp,
    isReadOnlyProp,
    isSelectedProp,
    defaultSelected,
    otherProps["aria-label"],
    otherProps["aria-labelledby"],
    onValueChange
  ]);
  const toggleState = (0, import_toggle.useToggleState)(ariaCheckboxProps);
  const {
    inputProps,
    isSelected,
    isDisabled,
    isReadOnly,
    isPressed: isPressedKeyboard
  } = isInGroup ? (
    // eslint-disable-next-line
    (0, import_checkbox.useCheckboxGroupItem)(
      {
        ...ariaCheckboxProps,
        isInvalid,
        validationBehavior: "native"
      },
      groupContext.groupState,
      inputRef
    )
  ) : (
    // eslint-disable-next-line
    (0, import_checkbox.useCheckbox)(
      { ...ariaCheckboxProps, validationBehavior: "native" },
      toggleState,
      inputRef
    )
  );
  const isInteractionDisabled = isDisabled || isReadOnly;
  const [isPressed, setPressed] = (0, import_react.useState)(false);
  const { pressProps } = (0, import_use_aria_press.usePress)({
    isDisabled: isInteractionDisabled,
    onPressStart(e) {
      if (e.pointerType !== "keyboard") {
        setPressed(true);
      }
    },
    onPressEnd(e) {
      if (e.pointerType !== "keyboard") {
        setPressed(false);
      }
    }
  });
  const pressed = isInteractionDisabled ? false : isPressed || isPressedKeyboard;
  if (isRequired) {
    inputProps.required = true;
  }
  const { hoverProps, isHovered } = (0, import_interactions.useHover)({
    isDisabled: inputProps.disabled
  });
  const { focusProps, isFocused, isFocusVisible } = (0, import_focus.useFocusRing)({
    autoFocus: inputProps.autoFocus
  });
  (0, import_use_safe_layout_effect.useSafeLayoutEffect)(() => {
    if (!inputRef.current)
      return;
    const isInputRefChecked = !!inputRef.current.checked;
    toggleState.setSelected(isInputRefChecked);
  }, [inputRef.current]);
  const onChangeProp = (0, import_use_callback_ref.useCallbackRef)(onChange);
  const handleCheckboxChange = (0, import_react.useCallback)(
    (event) => {
      if (isReadOnly || isDisabled) {
        event.preventDefault();
        return;
      }
      onChangeProp == null ? void 0 : onChangeProp(event);
    },
    [isReadOnly, isDisabled, onChangeProp]
  );
  const getBaseProps = (0, import_react.useCallback)(() => {
    return {
      ref: domRef,
      "data-disabled": (0, import_react_utils2.dataAttr)(isDisabled),
      "data-selected": (0, import_react_utils2.dataAttr)(isSelected || isIndeterminate),
      "data-hover": (0, import_react_utils2.dataAttr)(isHovered),
      "data-focus": (0, import_react_utils2.dataAttr)(isFocused),
      "data-pressed": (0, import_react_utils2.dataAttr)(pressed),
      "data-readonly": (0, import_react_utils2.dataAttr)(inputProps.readOnly),
      "data-focus-visible": (0, import_react_utils2.dataAttr)(isFocusVisible),
      "data-indeterminate": (0, import_react_utils2.dataAttr)(isIndeterminate),
      ...(0, import_utils.mergeProps)(hoverProps, pressProps, otherProps)
    };
  }, [
    isDisabled,
    isSelected,
    isIndeterminate,
    isHovered,
    isFocused,
    pressed,
    inputProps.readOnly,
    isFocusVisible,
    hoverProps,
    pressProps,
    otherProps
  ]);
  const getWrapperProps = (0, import_react.useCallback)((props2 = {}) => {
    return {
      ...props2,
      "aria-hidden": true
    };
  }, []);
  const getInputProps = (0, import_react.useCallback)(() => {
    return {
      ref: (0, import_react_utils2.mergeRefs)(inputRef, ref),
      ...(0, import_utils.mergeProps)(inputProps, focusProps),
      onChange: (0, import_utils.chain)(inputProps.onChange, handleCheckboxChange)
    };
  }, [inputProps, focusProps, handleCheckboxChange]);
  const getLabelProps = (0, import_react.useCallback)(
    () => ({
      id: labelId
    }),
    [isDisabled, isSelected]
  );
  const getIconProps = (0, import_react.useCallback)(
    () => ({
      isSelected,
      isIndeterminate: !!isIndeterminate
    }),
    [isSelected, isIndeterminate]
  );
  return {
    Component,
    icon,
    children,
    isSelected,
    isDisabled,
    isFocused,
    isHovered,
    isFocusVisible,
    getBaseProps,
    getWrapperProps,
    getInputProps,
    getLabelProps,
    getIconProps
  };
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  useCheckbox
});
